@@ -31,14 +31,14 @@ class CORSAppMixin:
             ("Access-Control-Allow-Credentials", "true"),
             (
                 "Access-Control-Allow-Methods",
-                ",".join(self._cors_allow_methods),
+                ",".join(self.__cors_allow_methods__),
             ),
             (
                 "Access-Control-Allow-Headers",
-                ",".join(self._cors_allow_headers),
+                ",".join(self.__cors_allow_headers__),
             ),
             (
                 "Access-Control-Expose-Headers",
-                ",".join(self._cors_expose_headers),
+                ",".join(self.__cors_expose_headers__),
             ),
         )
