@@ -40,7 +40,7 @@ class DatabaseAppMixin:
             CytraDBQuery.__app__ = self
             self.db = session
             DBSessionProxy.__cytra_session__ = session
-            self._cors_expose_headers.update(
+            self.__cors_expose_headers__.update(
                 (
                     "x-pagination-count",
                     "x-pagination-skip",
